summaryrefslogtreecommitdiffstats
path: root/zebra/zebra_vxlan_private.h
diff options
context:
space:
mode:
authorChirag Shah <chirag@cumulusnetworks.com>2017-06-22 01:37:51 +0200
committerDonald Sharp <sharpd@cumulusnetworks.com>2017-08-08 16:28:50 +0200
commitcd233079064f4b0fa8eacaf60d9fbd454ad47e30 (patch)
tree6ca660924e065c76746d95924fe0966fcacc5b8c /zebra/zebra_vxlan_private.h
parentzebra: Fix some memory leaks on shutdown (diff)
downloadfrr-cd233079064f4b0fa8eacaf60d9fbd454ad47e30.tar.xz
frr-cd233079064f4b0fa8eacaf60d9fbd454ad47e30.zip
zebra: Enable JSON for EVPN show cmds
Ticket: CM-16959 Reviewed By: CCR-6401 Testing Done: Execute 'show evpn .... json' form of outputs with local/remote vteps Signed-off-by: Chirag Shah <chirag@cumulusnetworks.com>
Diffstat (limited to 'zebra/zebra_vxlan_private.h')
-rw-r--r--zebra/zebra_vxlan_private.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/zebra/zebra_vxlan_private.h b/zebra/zebra_vxlan_private.h
index 2e5943a75..2bf00291e 100644
--- a/zebra/zebra_vxlan_private.h
+++ b/zebra/zebra_vxlan_private.h
@@ -135,8 +135,9 @@ struct mac_walk_ctx {
struct in_addr r_vtep_ip; /* To walk MACs from specific VTEP */
- struct vty *vty; /* Used by VTY handlers */
- u_int32_t count; /* Used by VTY handlers */
+ struct vty *vty; /* Used by VTY handlers */
+ u_int32_t count; /* Used by VTY handlers */
+ struct json_object *json; /* Used for JSON Output */
};
/*
@@ -186,9 +187,10 @@ struct neigh_walk_ctx {
struct in_addr r_vtep_ip; /* To walk neighbors from specific VTEP */
- struct vty *vty; /* Used by VTY handlers */
- u_int32_t count; /* Used by VTY handlers */
- u_char addr_width; /* Used by VTY handlers */
+ struct vty *vty; /* Used by VTY handlers */
+ u_int32_t count; /* Used by VTY handlers */
+ u_char addr_width; /* Used by VTY handlers */
+ struct json_object *json; /* Used for JSON Output */
};
#endif /* _ZEBRA_VXLAN_PRIVATE_H */